{% load i18n %}
<nav class="pagination" role="navigation" aria-label="pagination">
  <a class="pagination-previous" {% if page_obj.has_previous %}href="?page={{ page_ipage_objnstance.previous_page_number }}{% if parameters %}&{{ parameters }}{% endif %}" {% else %}disabled{% endif %}>{% trans "Previous" %}</a>
  <a class="pagination-next" {% if page_obj.has_next %}href="?page={{ page_obj.next_page_number }}{% if parameters %}&{{ parameters }}{% endif %}" {% else %}disabled{% endif %}>{% trans "Next" %}</a>
</nav>
