{% extends "backoffice/base.html" %}
{% load i18n %}

{% block body %}
{% block header %}
<nav class="navbar is-dark" role="navigation" aria-label="main navigation">
  <div class="navbar-brand">
    <a class="navbar-item" href="{{ index_url }}">
      {{ backoffice_title }}
    </a>
  </div>
  <div class="navbar-end">
    {% if request.user.is_authenticated %}
    <a class="navbar-item" href="{{ sign_out }}">
      {% trans "Sign out" %}
    </a>
    {% endif %}
  </div>
</nav>
{% endblock header %}
<section class="section columns">
  {% block section %}
  {% endblock section %}
</section>
{%  block footer %}
<footer class="footer">
  <div class="content has-text-centered">
    <p>
      {% blocktrans %}
      <strong>{{ backoffice_title }}</strong>'s backoffice panel.
      {% endblocktrans %}
    </p>
  </div>
</footer>
{%  endblock footer %}
{% endblock body %}