{% load i18n %}
<form method="get">
  <div class="control has-icons-left">
    <input class="input is-rounded" type="text" placeholder="{% trans "Search" %}..." name="search" value="{{ search }}">
    <span class="icon is-small is-left">
      <i class="fas fa-search"></i>
    </span>
  </div>
</form>
